==> kaidan-0.4.0.tar.xz: kaidan-0.4.0/src/Notifications.cpp <==
/*
 *  Kaidan - A user-friendly XMPP client for every device!
 *
 *  Copyright (C) 2016-2019 Kaidan developers and contributors
 *  (see the LICENSE file for a full list of copyright authors)
 *
 *  Kaidan is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  In addition, as a special exception, the author of Kaidan gives
 *  permission to link the code of its release with the OpenSSL
 *  project's "OpenSSL" library (or with modified versions of it that
 *  use the same license as the "OpenSSL" library), and distribute the
 *  linked executables. You must obey the GNU General Public License in
 *  all respects for all of the code used other than "OpenSSL". If you
 *  modify this file, you may extend this exception to your version of
 *  the file, but you are not obligated to do so.  If you do not wish to
 *  do so, delete this exception statement from your version.
 *
 *  Kaidan is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
 */

// Kaidan
#include "Notifications.h"
// KNotifications
#ifdef HAVE_KNOTIFICATIONS
#include <KNotification>
#endif

#ifdef HAVE_KNOTIFICATIONS
void Notifications::sendMessageNotification(const QString& fromName, const QString& message)
{
	KNotification *notif = new KNotification("new-message");
	notif->setText(QString("<b>%1</b>: %2").arg(fromName, message));
	notif->sendEvent();
}
#else
void Notifications::sendMessageNotification(const QString&, const QString&)
{
}
#endif

==> kaidan-0.5.0.tar.xz: kaidan-0.5.0/src/Notifications.cpp <==
/*
 *  Kaidan - A user-friendly XMPP client for every device!
 *
 *  Copyright (C) 2016-2020 Kaidan developers and contributors
 *  (see the LICENSE file for a full list of copyright authors)
 *
 *  Kaidan is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  In addition, as a special exception, the author of Kaidan gives
 *  permission to link the code of its release with the OpenSSL
 *  project's "OpenSSL" library (or with modified versions of it that
 *  use the same license as the "OpenSSL" library), and distribute the
 *  linked executables. You must obey the GNU General Public License in
 *  all respects for all of the code used other than "OpenSSL". If you
 *  modify this file, you may extend this exception to your version of
 *  the file, but you are not obligated to do so.  If you do not wish to
 *  do so, delete this exception statement from your version.
 *
 *  Kaidan is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
 */

// Kaidan
#include "Notifications.h"
#include "Kaidan.h"
// Qt
#include <QVariant>
// KNotifications
#ifdef HAVE_KNOTIFICATIONS
#include <KNotification>
#endif

#ifdef HAVE_KNOTIFICATIONS
void Notifications::sendMessageNotification(const QString& jid, const QString& fromName, const QString& message)
{
	if (!Kaidan::instance()->notificationsMuted(jid)) {
		KNotification *notification = new KNotification("new-message");
		notification->setText(message);
		notification->setTitle(fromName);
#ifdef Q_OS_ANDROID
		notification->setIconName("kaidan-bw");
#endif
		notification->setFlags(KNotification::Persistent);
		notification->sendEvent();
	}
}
#else
void Notifications::sendMessageNotification(const QString&, const QString&, const QString&)
{
}
#endif
